package com.wst.data.safety.datasource.tool.util;

import com.google.common.collect.Maps;
import com.wst.data.safety.datasource.tool.datax.MetadataColumn;
import com.wst.data.safety.datasource.tool.datax.Record;
import com.wst.data.safety.datasource.tool.datax.StringColumn;
import com.wst.data.safety.datasource.tool.dto.DataSourceInfoDTO;
import com.wst.data.safety.datasource.tool.dto.TableDTO;
import com.wst.data.safety.datasource.tool.entity.JobRecord;
import com.wst.data.safety.datasource.tool.entity.ProxyConnection;
import com.wst.data.safety.datasource.tool.entity.ProxyResultSet;
import com.wst.data.safety.datasource.tool.entity.RecordMetaData;
import com.wst.data.safety.datasource.tool.exception.DataToolkitException;
import com.wst.data.safety.datasource.tool.returnvalue.FetchByRangeReturnValue;
import java.io.Reader;
import java.math.BigDecimal;
import java.math.RoundingMode;
import java.sql.Blob;
import java.sql.Clob;
import java.sql.Connection;
import java.sql.DatabaseMetaData;
import java.sql.Driver;
import java.sql.NClob;
import java.sql.ResultSet;
import java.sql.ResultSetMetaData;
import java.sql.SQLException;
import java.sql.Statement;
import java.util.ArrayList;
import java.util.HashMap;
import java.util.List;
import java.util.Map;
import java.util.Properties;
import org.apache.commons.lang.StringUtils;
import org.apache.metamodel.DataContextFactory;
import org.apache.metamodel.UpdateableDataContext;
import org.apache.metamodel.jdbc.JdbcDataContext;
import org.apache.metamodel.jdbc.JdbcUtils;
import org.apache.metamodel.schema.Column;
import org.apache.metamodel.schema.Schema;
import org.apache.metamodel.schema.Table;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.stereotype.Service;

@Service
/* loaded from: TablelUtil.class */
public class TablelUtil {
    private static final Logger log = LoggerFactory.getLogger(TablelUtil.class);
    private static final String ORACLE = "ORACLE";
    private static final String CLICKHOUSE = "CLICKHOUSE";
    private static final String DM = "DM";
    private static final String MYSQL = "MYSQL";
    private static final String MARIADB = "MARIADB";
    private static final String GBASE = "GBASE";
    private static final String GBASE8S = "GBASE8S";
    private static final String DB_2 = "DB2";
    private static final String KINGBASE = "KINGBASE";
    private static final String OSCAR = "OSCAR";
    private static final String GREENPLUM = "GREENPLUM";
    private static final String POSTGRE_SQL = "PostgreSQL";
    private static final String HIVE = "Hive";
    private static final String POSTGRESQL = "POSTGRESQL";
    private static final String FILE = "FILE";
    private static final String HBASE = "HBASE";
    private static final String SQLSERVER = "SQLSERVER";
    private static final String STORAGE = "STORAGE";
    private static final String SEGMENT_ATTRIBUTES = "SEGMENT_ATTRIBUTES";
    private static final String TABLESPACE = "TABLESPACE";
    private static final String SQLTERMINATOR = "SQLTERMINATOR";
    private static final String CONSTRAINTS = "CONSTRAINTS";
    private static final String REF_CONSTRAINTS = "REF_CONSTRAINTS";
    private static final String FETCH_BY_RANGE_ERROR = "fetchByRange-error:{}";
    private static final String SELECT_COUNT_0_FROM = "SELECT COUNT(0) FROM";
    private static final String DBMS_METADATA_SET_TRANSFORM_PARAM = "DBMS_METADATA.SET_TRANSFORM_PARAM";
    private static final String DBMS_METADATA_SESSION_TRANSFORM = "DBMS_METADATA.SESSION_TRANSFORM";
    private static final String SELECT_TABLE_NAME_SQL = "select table_name from information_schema.tables where table_schema";

    public static Double getTableSize(Statement statement, TableDTO tableDTO) throws SQLException {
        String sql = "";
        double tableSize = 0.0d;
        if (tableDTO.getType().equalsIgnoreCase(ORACLE) || DM.equalsIgnoreCase(tableDTO.getType())) {
            sql = "select sum(bytes)/1024 as data_size from dba_segments where segment_name='" + tableDTO.getTableName() + "'";
        } else if (tableDTO.getType().equalsIgnoreCase(CLICKHOUSE)) {
            sql = "select sum(bytes) as data_size from `system`.parts where active and database ='" + tableDTO.getSchemaName() + "' and `table` ='" + tableDTO.getTableName() + "'";
        } else if (tableDTO.getType().equalsIgnoreCase(MYSQL) || tableDTO.getType().equalsIgnoreCase(MARIADB) || tableDTO.getType().equalsIgnoreCase(GBASE)) {
            sql = "select concat(truncate(data_length/1024,2)) as data_size from information_schema.tables where TABLE_SCHEMA = '" + tableDTO.getSchemaName() + "' and table_name = '" + tableDTO.getTableName() + "'";
        } else if (tableDTO.getType().equalsIgnoreCase(SQLSERVER)) {
            sql = "exec sp_spaceused[" + tableDTO.getTableName() + "]";
        } else if (tableDTO.getType().equalsIgnoreCase(DB_2)) {
            sql = "select sum(x.DATA_OBJECT_P_SIZE+x.INDEX_OBJECT_P_SIZE+x.LOB_OBJECT_P_SIZE+x.LONG_OBJECT_P_SIZE+x.XML_OBJECT_P_SIZE) from SYSIBMADM.ADMINTABINFO x where TABNAME = '" + tableDTO.getTableName() + "'";
        } else if (tableDTO.getType().equalsIgnoreCase(KINGBASE)) {
            if (tableDTO.getVersion() != null && tableDTO.getVersion().equalsIgnoreCase("KINGBASE 7.1.2")) {
                return Double.valueOf(0.0d);
            }
            sql = "select sys_table_size(oid)/1024 from sys_class a where relname = '" + tableDTO.getTableName() + "'";
        } else if (OSCAR.equalsIgnoreCase(tableDTO.getType())) {
            sql = "select size/1024 from v_segment_info, sys_class where relname = '" + tableDTO.getTableName() + "' and relid = oid";
        } else if (GREENPLUM.equalsIgnoreCase(tableDTO.getType())) {
            sql = "select pg_size_pretty(pg_relation_size('\"" + tableDTO.getSchemaName() + "\"." + tableDTO.getTableName() + "'))";
        } else if (POSTGRE_SQL.equalsIgnoreCase(tableDTO.getType())) {
            if (StringUtils.isNotBlank(tableDTO.getSchemaName())) {
                StringBuilder schemaName = new StringBuilder(tableDTO.getSchemaName());
                if (tableDTO.getSchemaName().startsWith("'")) {
                    schemaName.replace(0, 1, "");
                    if (tableDTO.getSchemaName().endsWith("'")) {
                        schemaName.replace(tableDTO.getSchemaName().length() - 2, tableDTO.getSchemaName().length() - 1, "");
                    }
                }
                tableDTO.setSchemaName(schemaName.toString());
            }
            if (tableDTO.getTableName().startsWith(tableDTO.getSchemaName()) && tableDTO.getTableName().indexOf(".") > -1) {
                StringBuilder sb = new StringBuilder(tableDTO.getTableName());
                sb.replace(0, tableDTO.getTableName().indexOf(".") + 1, "");
                tableDTO.setTableName(sb.toString());
            }
            sql = "select pg_size_pretty(pg_total_relation_size('\"' || table_schema || '\".\"' || table_name || '\"'))as size   from  information_schema.tables   where table_schema='" + tableDTO.getSchemaName() + "'and table_name ='" + tableDTO.getTableName() + "'";
        }
        ResultSet res = null;
        try {
            if (tableDTO.getType().equalsIgnoreCase(HIVE) || tableDTO.getType().equalsIgnoreCase(GBASE8S)) {
                tableSize = 0.0d;
            } else if (tableDTO.getType().equalsIgnoreCase(SQLSERVER)) {
                log.info("get table sql : " + sql);
                res = statement.executeQuery(sql);
                while (res.next()) {
                    String str = res.getString(4);
                    if (str == null) {
                        tableSize = 0.0d;
                    } else {
                        tableSize = Integer.parseInt(str.split(" ")[0]);
                    }
                }
            } else if (tableDTO.getType().equalsIgnoreCase(GREENPLUM) || tableDTO.getType().equalsIgnoreCase(POSTGRESQL)) {
                res = statement.executeQuery(sql);
                while (res.next()) {
                    String tables = res.getString(1);
                    int i = NumberCaseUtil.indexOfFirstUpperCase(tables);
                    String unit = tables.substring(i, tables.length());
                    tableSize = Double.parseDouble(tables.substring(0, i));
                    if (unit.equalsIgnoreCase("bytes")) {
                        tableSize /= 1024.0d;
                    } else if (unit.equalsIgnoreCase("MB")) {
                        tableSize *= 1024.0d;
                    } else if (unit.equalsIgnoreCase("gb")) {
                        tableSize = tableSize * 1024.0d * 1024.0d;
                    }
                }
            } else {
                log.info("get table sql : " + sql);
                res = statement.executeQuery(sql);
                while (res.next()) {
                    tableSize = res.getLong(1);
                }
            }
            BigDecimal decimal = BigDecimal.valueOf(tableSize / 1024.0d);
            Double valueOf = Double.valueOf(decimal.setScale(4, RoundingMode.HALF_UP).doubleValue());
            if (res != null) {
                try {
                    res.close();
                } catch (Exception e) {
                    log.error("close resultSet error", e);
                }
            }
            return valueOf;
        } catch (Throwable th) {
            if (res != null) {
                try {
                    res.close();
                } catch (Exception e2) {
                    log.error("close resultSet error", e2);
                }
            }
            throw th;
        }
    }

    public static int getRowCount(Statement statement, TableDTO tableDTO) throws SQLException {
        String sql = "";
        int rowCount = 0;
        String upperCase = tableDTO.getType().toUpperCase();
        boolean z = -1;
        switch (upperCase.hashCode()) {
            case -1955532418:
                if (upperCase.equals(ORACLE)) {
                    z = 3;
                    break;
                }
                break;
            case -1620389036:
                if (upperCase.equals(POSTGRESQL)) {
                    z = 12;
                    break;
                }
                break;
            case -283630952:
                if (upperCase.equals(CLICKHOUSE)) {
                    z = 6;
                    break;
                }
                break;
            case 2185:
                if (upperCase.equals(DM)) {
                    z = 9;
                    break;
                }
                break;
            case 67444:
                if (upperCase.equals(DB_2)) {
                    z = 11;
                    break;
                }
                break;
            case 2157948:
                if (upperCase.equals(FILE)) {
                    z = false;
                    break;
                }
                break;
            case 67601304:
                if (upperCase.equals(GBASE)) {
                    z = 13;
                    break;
                }
                break;
            case 68524825:
                if (upperCase.equals(HBASE)) {
                    z = true;
                    break;
                }
                break;
            case 73844866:
                if (upperCase.equals(MYSQL)) {
                    z = 8;
                    break;
                }
                break;
            case 75497296:
                if (upperCase.equals(OSCAR)) {
                    z = 5;
                    break;
                }
                break;
            case 230723304:
                if (upperCase.equals(KINGBASE)) {
                    z = 4;
                    break;
                }
                break;
            case 540345523:
                if (upperCase.equals(GBASE8S)) {
                    z = 14;
                    break;
                }
                break;
            case 559428343:
                if (upperCase.equals(GREENPLUM)) {
                    z = 10;
                    break;
                }
                break;
            case 912124529:
                if (upperCase.equals(SQLSERVER)) {
                    z = 2;
                    break;
                }
                break;
            case 1557169620:
                if (upperCase.equals(MARIADB)) {
                    z = 7;
                    break;
                }
                break;
        }
        switch (z) {
            case false:
            case true:
                break;
            case true:
                sql = "SELECT COUNT(0) FROM  " + tableDTO.getSchemaName() + ".[" + tableDTO.getTableName() + "]";
                break;
            case true:
            case true:
            case true:
                if (tableDTO.getVersion() != null && tableDTO.getVersion().equalsIgnoreCase("KINGBASE 7.1.2")) {
                    sql = "SELECT COUNT(0) FROM  \"" + tableDTO.getSchemaName() + "\".\"" + tableDTO.getTableName() + "\"";
                    break;
                } else {
                    sql = "SELECT COUNT(0) FROM  " + tableDTO.getSchemaName() + ".\"" + tableDTO.getTableName() + "\"";
                    break;
                }
                break;
            case true:
            case true:
                sql = "SELECT COUNT(0) FROM  " + tableDTO.getSchemaName() + ".`" + tableDTO.getTableName() + "`";
                break;
            case true:
                sql = "SELECT COUNT(0) FROM  `" + tableDTO.getSchemaName() + "`.`" + tableDTO.getTableName() + "`";
                break;
            case true:
            case true:
            case true:
            case true:
                sql = "SELECT COUNT(0) FROM \"" + tableDTO.getSchemaName() + "\".\"" + tableDTO.getTableName() + "\"";
                break;
            case true:
            case true:
                sql = "SELECT COUNT(0) FROM  " + tableDTO.getTableName();
                break;
            default:
                sql = "SELECT COUNT(0) FROM  " + tableDTO.getSchemaName() + "." + tableDTO.getTableName();
                break;
        }
        log.info("get row count sql : " + sql);
        ResultSet res = statement.executeQuery(sql);
        Throwable th = null;
        while (res.next()) {
            try {
                try {
                    rowCount = res.getInt(1);
                } finally {
                }
            } catch (Throwable th2) {
                if (res != null) {
                    if (th != null) {
                        try {
                            res.close();
                        } catch (Throwable th3) {
                            th.addSuppressed(th3);
                        }
                    } else {
                        res.close();
                    }
                }
                throw th2;
            }
        }
        int i = rowCount;
        if (res != null) {
            if (0 != 0) {
                try {
                    res.close();
                } catch (Throwable th4) {
                    th.addSuppressed(th4);
                }
            } else {
                res.close();
            }
        }
        return i;
    }

    public static String getOracleCreateTableDDL(Statement statement, TableDTO tableDTO) {
        String ddl = "";
        String sql = "SELECT Dbms_Metadata.Get_Ddl('TABLE','" + tableDTO.getTableName() + "','" + tableDTO.getSchemaName() + "') FROM dual";
        ResultSet rs = null;
        try {
            try {
                statement.execute(sql);
                rs = statement.getResultSet();
                while (rs.next()) {
                    ddl = rs.getString(1);
                }
                if (rs != null) {
                    try {
                        rs.close();
                    } catch (Exception e) {
                        log.error("close rs error", e);
                    }
                }
            } catch (Exception e2) {
                e2.printStackTrace();
                if (rs != null) {
                    try {
                        rs.close();
                    } catch (Exception e3) {
                        log.error("close rs error", e3);
                    }
                }
            }
            return ddl;
        } catch (Throwable th) {
            if (rs != null) {
                try {
                    rs.close();
                } catch (Exception e4) {
                    log.error("close rs error", e4);
                }
            }
            throw th;
        }
    }

    /* JADX WARN: Failed to apply debug info
    java.lang.NullPointerException: Cannot invoke "jadx.core.dex.instructions.args.InsnArg.getType()" because "changeArg" is null
    	at jadx.core.dex.visitors.typeinference.TypeUpdate.moveListener(TypeUpdate.java:439)
    	at jadx.core.dex.visitors.typeinference.TypeUpdate.runListeners(TypeUpdate.java:232)
    	at jadx.core.dex.visitors.typeinference.TypeUpdate.requestUpdate(TypeUpdate.java:212)
    	at jadx.core.dex.visitors.typeinference.TypeUpdate.updateTypeForSsaVar(TypeUpdate.java:183)
    	at jadx.core.dex.visitors.typeinference.TypeUpdate.updateTypeChecked(TypeUpdate.java:112)
    	at jadx.core.dex.visitors.typeinference.TypeUpdate.apply(TypeUpdate.java:83)
    	at jadx.core.dex.visitors.typeinference.TypeUpdate.applyWithWiderIgnoreUnknown(TypeUpdate.java:74)
    	at jadx.core.dex.visitors.debuginfo.DebugInfoApplyVisitor.applyDebugInfo(DebugInfoApplyVisitor.java:137)
    	at jadx.core.dex.visitors.debuginfo.DebugInfoApplyVisitor.applyDebugInfo(DebugInfoApplyVisitor.java:133)
    	at jadx.core.dex.visitors.debuginfo.DebugInfoApplyVisitor.searchAndApplyVarDebugInfo(DebugInfoApplyVisitor.java:75)
    	at jadx.core.dex.visitors.debuginfo.DebugInfoApplyVisitor.lambda$applyDebugInfo$0(DebugInfoApplyVisitor.java:68)
    	at java.base/java.util.ArrayList.forEach(ArrayList.java:1597)
    	at jadx.core.dex.visitors.debuginfo.DebugInfoApplyVisitor.applyDebugInfo(DebugInfoApplyVisitor.java:68)
    	at jadx.core.dex.visitors.debuginfo.DebugInfoApplyVisitor.visit(DebugInfoApplyVisitor.java:55)
     */
    /* JADX WARN: Failed to calculate best type for var: r10v0 ??
    java.lang.NullPointerException: Cannot invoke "jadx.core.dex.instructions.args.InsnArg.getType()" because "changeArg" is null
    	at jadx.core.dex.visitors.typeinference.TypeUpdate.moveListener(TypeUpdate.java:439)
    	at jadx.core.dex.visitors.typeinference.TypeUpdate.runListeners(TypeUpdate.java:232)
    	at jadx.core.dex.visitors.typeinference.TypeUpdate.requestUpdate(TypeUpdate.java:212)
    	at jadx.core.dex.visitors.typeinference.TypeUpdate.updateTypeForSsaVar(TypeUpdate.java:183)
    	at jadx.core.dex.visitors.typeinference.TypeUpdate.updateTypeChecked(TypeUpdate.java:112)
    	at jadx.core.dex.visitors.typeinference.TypeUpdate.apply(TypeUpdate.java:83)
    	at jadx.core.dex.visitors.typeinference.TypeUpdate.apply(TypeUpdate.java:56)
    	at jadx.core.dex.visitors.typeinference.FixTypesVisitor.calculateFromBounds(FixTypesVisitor.java:156)
    	at jadx.core.dex.visitors.typeinference.FixTypesVisitor.setBestType(FixTypesVisitor.java:133)
    	at jadx.core.dex.visitors.typeinference.FixTypesVisitor.deduceType(FixTypesVisitor.java:238)
    	at jadx.core.dex.visitors.typeinference.FixTypesVisitor.tryDeduceTypes(FixTypesVisitor.java:221)
    	at jadx.core.dex.visitors.typeinference.FixTypesVisitor.visit(FixTypesVisitor.java:91)
     */
    /* JADX WARN: Failed to calculate best type for var: r10v0 ??
    java.lang.NullPointerException: Cannot invoke "jadx.core.dex.instructions.args.InsnArg.getType()" because "changeArg" is null
    	at jadx.core.dex.visitors.typeinference.TypeUpdate.moveListener(TypeUpdate.java:439)
    	at jadx.core.dex.visitors.typeinference.TypeUpdate.runListeners(TypeUpdate.java:232)
    	at jadx.core.dex.visitors.typeinference.TypeUpdate.requestUpdate(TypeUpdate.java:212)
    	at jadx.core.dex.visitors.typeinference.TypeUpdate.updateTypeForSsaVar(TypeUpdate.java:183)
    	at jadx.core.dex.visitors.typeinference.TypeUpdate.updateTypeChecked(TypeUpdate.java:112)
    	at jadx.core.dex.visitors.typeinference.TypeUpdate.apply(TypeUpdate.java:83)
    	at jadx.core.dex.visitors.typeinference.TypeUpdate.apply(TypeUpdate.java:56)
    	at jadx.core.dex.visitors.typeinference.TypeInferenceVisitor.calculateFromBounds(TypeInferenceVisitor.java:145)
    	at jadx.core.dex.visitors.typeinference.TypeInferenceVisitor.setBestType(TypeInferenceVisitor.java:123)
    	at jadx.core.dex.visitors.typeinference.TypeInferenceVisitor.lambda$runTypePropagation$2(TypeInferenceVisitor.java:101)
    	at java.base/java.util.ArrayList.forEach(ArrayList.java:1597)
    	at jadx.core.dex.visitors.typeinference.TypeInferenceVisitor.runTypePropagation(TypeInferenceVisitor.java:101)
    	at jadx.core.dex.visitors.typeinference.TypeInferenceVisitor.visit(TypeInferenceVisitor.java:75)
     */
    /* JADX WARN: Failed to calculate best type for var: r11v0 ??
    java.lang.NullPointerException: Cannot invoke "jadx.core.dex.instructions.args.InsnArg.getType()" because "changeArg" is null
    	at jadx.core.dex.visitors.typeinference.TypeUpdate.moveListener(TypeUpdate.java:439)
    	at jadx.core.dex.visitors.typeinference.TypeUpdate.runListeners(TypeUpdate.java:232)
    	at jadx.core.dex.visitors.typeinference.TypeUpdate.requestUpdate(TypeUpdate.java:212)
    	at jadx.core.dex.visitors.typeinference.TypeUpdate.updateTypeForSsaVar(TypeUpdate.java:183)
    	at jadx.core.dex.visitors.typeinference.TypeUpdate.updateTypeChecked(TypeUpdate.java:112)
    	at jadx.core.dex.visitors.typeinference.TypeUpdate.apply(TypeUpdate.java:83)
    	at jadx.core.dex.visitors.typeinference.TypeUpdate.apply(TypeUpdate.java:56)
    	at jadx.core.dex.visitors.typeinference.FixTypesVisitor.calculateFromBounds(FixTypesVisitor.java:156)
    	at jadx.core.dex.visitors.typeinference.FixTypesVisitor.setBestType(FixTypesVisitor.java:133)
    	at jadx.core.dex.visitors.typeinference.FixTypesVisitor.deduceType(FixTypesVisitor.java:238)
    	at jadx.core.dex.visitors.typeinference.FixTypesVisitor.tryDeduceTypes(FixTypesVisitor.java:221)
    	at jadx.core.dex.visitors.typeinference.FixTypesVisitor.visit(FixTypesVisitor.java:91)
     */
    /* JADX WARN: Failed to calculate best type for var: r11v0 ??
    java.lang.NullPointerException: Cannot invoke "jadx.core.dex.instructions.args.InsnArg.getType()" because "changeArg" is null
    	at jadx.core.dex.visitors.typeinference.TypeUpdate.moveListener(TypeUpdate.java:439)
    	at jadx.core.dex.visitors.typeinference.TypeUpdate.runListeners(TypeUpdate.java:232)
    	at jadx.core.dex.visitors.typeinference.TypeUpdate.requestUpdate(TypeUpdate.java:212)
    	at jadx.core.dex.visitors.typeinference.TypeUpdate.updateTypeForSsaVar(TypeUpdate.java:183)
    	at jadx.core.dex.visitors.typeinference.TypeUpdate.updateTypeChecked(TypeUpdate.java:112)
    	at jadx.core.dex.visitors.typeinference.TypeUpdate.apply(TypeUpdate.java:83)
    	at jadx.core.dex.visitors.typeinference.TypeUpdate.apply(TypeUpdate.java:56)
    	at jadx.core.dex.visitors.typeinference.TypeInferenceVisitor.calculateFromBounds(TypeInferenceVisitor.java:145)
    	at jadx.core.dex.visitors.typeinference.TypeInferenceVisitor.setBestType(TypeInferenceVisitor.java:123)
    	at jadx.core.dex.visitors.typeinference.TypeInferenceVisitor.lambda$runTypePropagation$2(TypeInferenceVisitor.java:101)
    	at java.base/java.util.ArrayList.forEach(ArrayList.java:1597)
    	at jadx.core.dex.visitors.typeinference.TypeInferenceVisitor.runTypePropagation(TypeInferenceVisitor.java:101)
    	at jadx.core.dex.visitors.typeinference.TypeInferenceVisitor.visit(TypeInferenceVisitor.java:75)
     */
    /* JADX WARN: Multi-variable type inference failed. Error: java.lang.NullPointerException: Cannot invoke "jadx.core.dex.instructions.args.RegisterArg.getSVar()" because the return value of "jadx.core.dex.nodes.InsnNode.getResult()" is null
    	at jadx.core.dex.visitors.typeinference.AbstractTypeConstraint.collectRelatedVars(AbstractTypeConstraint.java:31)
    	at jadx.core.dex.visitors.typeinference.AbstractTypeConstraint.<init>(AbstractTypeConstraint.java:19)
    	at jadx.core.dex.visitors.typeinference.TypeSearch$1.<init>(TypeSearch.java:376)
    	at jadx.core.dex.visitors.typeinference.TypeSearch.makeMoveConstraint(TypeSearch.java:376)
    	at jadx.core.dex.visitors.typeinference.TypeSearch.makeConstraint(TypeSearch.java:361)
    	at jadx.core.dex.visitors.typeinference.TypeSearch.collectConstraints(TypeSearch.java:341)
    	at java.base/java.util.ArrayList.forEach(ArrayList.java:1597)
    	at jadx.core.dex.visitors.typeinference.TypeSearch.run(TypeSearch.java:60)
    	at jadx.core.dex.visitors.typeinference.FixTypesVisitor.runMultiVariableSearch(FixTypesVisitor.java:116)
    	at jadx.core.dex.visitors.typeinference.FixTypesVisitor.visit(FixTypesVisitor.java:91)
     */
    /* JADX WARN: Not initialized variable reg: 10, insn: 0x0140: MOVE (r0 I:??[int, float, boolean, short, byte, char, OBJECT, ARRAY]) = (r10 I:??[int, float, boolean, short, byte, char, OBJECT, ARRAY] A[D('statement' java.sql.Statement)]) A[TRY_LEAVE], block:B:68:0x0140 */
    /* JADX WARN: Not initialized variable reg: 11, insn: 0x0145: MOVE (r0 I:??[int, float, boolean, short, byte, char, OBJECT, ARRAY]) = (r11 I:??[int, float, boolean, short, byte, char, OBJECT, ARRAY]), block:B:70:0x0145 */
    /* JADX WARN: Type inference failed for: r10v0, names: [statement], types: [java.sql.Statement] */
    /* JADX WARN: Type inference failed for: r11v0, types: [java.lang.Throwable] */
    public static Map<String, String> getPartitionTableSql(List<String> tableNames, ProxyConnection proxyConnection) {
        Connection conn = (Connection) proxyConnection.getConnection();
        String schemaName = proxyConnection.getDataSourceInfo().getSchema();
        Map<String, String> tableSql = new HashMap<>();
        try {
            try {
                Statement createStatement = conn.createStatement();
                Throwable th = null;
                for (String str : tableNames) {
                    createStatement.execute("begin\n DBMS_METADATA.SET_TRANSFORM_PARAM(DBMS_METADATA.SESSION_TRANSFORM,'STORAGE',FALSE); --去掉存储字句\n DBMS_METADATA.SET_TRANSFORM_PARAM(DBMS_METADATA.SESSION_TRANSFORM,'SEGMENT_ATTRIBUTES', false);--去掉prtfree字句\n DBMS_METADATA.SET_TRANSFORM_PARAM(DBMS_METADATA.SESSION_TRANSFORM,'TABLESPACE', false);--去掉表空间子句\n DBMS_METADATA.SET_TRANSFORM_PARAM(DBMS_METADATA.SESSION_TRANSFORM,'SQLTERMINATOR', FALSE ); --加上分号\n DBMS_METADATA.SET_TRANSFORM_PARAM(DBMS_METADATA.SESSION_TRANSFORM,'CONSTRAINTS', false); end;");
                    createStatement.execute("SELECT Dbms_Metadata.Get_Ddl('TABLE','" + str + "','" + schemaName + "') FROM dual");
                    ResultSet resultSet = createStatement.getResultSet();
                    Throwable th2 = null;
                    while (resultSet.next()) {
                        try {
                            try {
                                tableSql.put(str, resultSet.getString(1));
                            } finally {
                            }
                        } catch (Throwable th3) {
                            if (resultSet != null) {
                                if (th2 != null) {
                                    try {
                                        resultSet.close();
                                    } catch (Throwable th4) {
                                        th2.addSuppressed(th4);
                                    }
                                } else {
                                    resultSet.close();
                                }
                            }
                            throw th3;
                        }
                    }
                    if (resultSet != null) {
                        if (0 != 0) {
                            try {
                                resultSet.close();
                            } catch (Throwable th5) {
                                th2.addSuppressed(th5);
                            }
                        } else {
                            resultSet.close();
                        }
                    }
                }
                if (createStatement != null) {
                    if (0 != 0) {
                        try {
                            createStatement.close();
                        } catch (Throwable th6) {
                            th.addSuppressed(th6);
                        }
                    } else {
                        createStatement.close();
                    }
                }
            } finally {
            }
        } catch (SQLException e) {
            e.printStackTrace();
        }
        return tableSql;
    }

    public static List getTableColum(TableDTO tableDTO) throws SQLException {
        String sql = "";
        List tableColum = new ArrayList();
        List temporary = new ArrayList();
        if (!SQLSERVER.equalsIgnoreCase(tableDTO.getType())) {
            tableDTO.setSchemaName("'" + tableDTO.getSchemaName() + "'");
        }
        if (SQLSERVER.equalsIgnoreCase(tableDTO.getType())) {
            tableDTO.setSchemaName("'" + tableDTO.getSchemaName() + "'");
            sql = "select Distinct name from" + tableDTO.getSchemaName() + "..sysobjects where xtype='u'";
        } else if (MYSQL.equalsIgnoreCase(tableDTO.getType()) || MARIADB.equalsIgnoreCase(tableDTO.getType())) {
            sql = "select table_name from information_schema.tables where table_schema=" + tableDTO.getSchemaName();
        } else if (ORACLE.equalsIgnoreCase(tableDTO.getType())) {
            sql = "select table_name from dba_tables where owner=" + tableDTO.getSchemaName();
        } else if (DB_2.equalsIgnoreCase(tableDTO.getType())) {
            sql = "select name from sysibm.systables where type='T' and creator=" + tableDTO.getSchemaName();
        } else if (POSTGRE_SQL.equalsIgnoreCase(tableDTO.getType())) {
            sql = "select*from pg_tables where schemaname =" + tableDTO.getSchemaName();
        }
        ResultSet res = tableDTO.getStatement().executeQuery(sql);
        while (res.next()) {
            String str = res.getString(1);
            tableColum.add(str);
            temporary.add(str);
        }
        if (SQLSERVER.equalsIgnoreCase(tableDTO.getType()) && temporary.size() > 0) {
            tableColum.clear();
            for (int m = 0; m < temporary.size() - 1; m++) {
                String sql1 = "SELECT Distinct c.TABLE_SCHEMA ,c.TABLE_NAME FROM    [INFORMATION_SCHEMA].[COLUMNS] c WHERE   TABLE_NAME ='" + temporary.get(m) + "'";
                ResultSet rest = tableDTO.getStatement().executeQuery(sql1);
                while (rest.next()) {
                    String pattern = rest.getString(1);
                    String surface = rest.getString(2);
                    String index = pattern + ".[" + surface + "]";
                    tableColum.add(index);
                }
            }
        } else if (POSTGRE_SQL.equalsIgnoreCase(tableDTO.getType())) {
            tableColum.clear();
            ResultSet rest2 = tableDTO.getStatement().executeQuery(sql);
            while (rest2.next()) {
                String pattern2 = rest2.getString(1);
                String surface2 = rest2.getString(2);
                String index2 = pattern2 + "." + surface2;
                tableColum.add(index2);
            }
        }
        return tableColum;
    }

    public static List getHermesTableColum(Statement statement, TableDTO tableDTO) throws SQLException {
        String sql = "";
        List<String> tableColum = new ArrayList<>();
        List<String> temporary = new ArrayList<>();
        if (!SQLSERVER.equalsIgnoreCase(tableDTO.getType())) {
            tableDTO.setSchemaName("'" + tableDTO.getSchemaName() + "'");
        }
        String upperCase = tableDTO.getType().toUpperCase();
        boolean z = -1;
        switch (upperCase.hashCode()) {
            case -1955532418:
                if (upperCase.equals(ORACLE)) {
                    z = false;
                    break;
                }
                break;
            case -1620389036:
                if (upperCase.equals(POSTGRESQL)) {
                    z = 10;
                    break;
                }
                break;
            case 2185:
                if (upperCase.equals(DM)) {
                    z = true;
                    break;
                }
                break;
            case 67444:
                if (upperCase.equals(DB_2)) {
                    z = 6;
                    break;
                }
                break;
            case 67601304:
                if (upperCase.equals(GBASE)) {
                    z = 4;
                    break;
                }
                break;
            case 73844866:
                if (upperCase.equals(MYSQL)) {
                    z = 2;
                    break;
                }
                break;
            case 75497296:
                if (upperCase.equals(OSCAR)) {
                    z = 8;
                    break;
                }
                break;
            case 230723304:
                if (upperCase.equals(KINGBASE)) {
                    z = 7;
                    break;
                }
                break;
            case 559428343:
                if (upperCase.equals(GREENPLUM)) {
                    z = 9;
                    break;
                }
                break;
            case 912124529:
                if (upperCase.equals(SQLSERVER)) {
                    z = 5;
                    break;
                }
                break;
            case 1557169620:
                if (upperCase.equals(MARIADB)) {
                    z = 3;
                    break;
                }
                break;
        }
        switch (z) {
            case false:
                sql = "select table_name from dba_tables where owner =" + tableDTO.getSchemaName();
                break;
            case true:
                sql = "select table_name from dba_tables where owner =" + tableDTO.getSchemaName();
                break;
            case true:
            case true:
                sql = "select table_name from information_schema.tables where table_schema=" + tableDTO.getSchemaName();
                break;
            case true:
                sql = "select table_name from information_schema.tables where table_schema=" + tableDTO.getSchemaName();
                break;
            case true:
                sql = "select Distinct name from  .sysobjects where xtype='u'";
                break;
            case true:
                sql = "select name from sysibm.systables where type='T' and creator=" + tableDTO.getSchemaName();
                break;
            case true:
                sql = "select table_name from information_schema.tables where table_schema=" + tableDTO.getSchemaName();
                break;
            case true:
                sql = "select relname table_name from sys_class, sys_namespace nsp where nsp.oid = relnamespace and relkind = 'r' and nsp.nspname =" + tableDTO.getSchemaName();
                break;
            case true:
                sql = "select tablename from pg_tables where schemaname = " + tableDTO.getSchemaName();
                break;
            case true:
                sql = "select tablename from pg_tables where schemaname=" + tableDTO.getSchemaName();
                break;
        }
        if (sql != "") {
            ResultSet res = statement.executeQuery(sql);
            Throwable th = null;
            while (res.next()) {
                try {
                    try {
                        String str = res.getString(1);
                        tableColum.add(str);
                        temporary.add(str);
                    } finally {
                    }
                } catch (Throwable th2) {
                    if (res != null) {
                        if (th != null) {
                            try {
                                res.close();
                            } catch (Throwable th3) {
                                th.addSuppressed(th3);
                            }
                        } else {
                            res.close();
                        }
                    }
                    throw th2;
                }
            }
            if ("Sqlserver".equalsIgnoreCase(tableDTO.getType()) && temporary.size() > 0) {
                tableColum.clear();
                for (int m = 0; m < temporary.size(); m++) {
                    String sql1 = "SELECT Distinct c.TABLE_SCHEMA ,c.TABLE_NAME FROM    [INFORMATION_SCHEMA].[COLUMNS] c WHERE   TABLE_NAME ='" + temporary.get(m) + "'and TABLE_SCHEMA='" + tableDTO.getSchemaName() + "'";
                    ResultSet rest = statement.executeQuery(sql1);
                    Throwable th4 = null;
                    while (rest.next()) {
                        try {
                            try {
                                String pattern = rest.getString(1);
                                String surface = rest.getString(2);
                                String index = pattern + ".[" + surface + "]";
                                tableColum.add(index);
                            } finally {
                            }
                        } finally {
                        }
                    }
                    if (rest != null) {
                        if (0 != 0) {
                            try {
                                rest.close();
                            } catch (Throwable th5) {
                                th4.addSuppressed(th5);
                            }
                        } else {
                            rest.close();
                        }
                    }
                }
            }
            if (res != null) {
                if (0 != 0) {
                    try {
                        res.close();
                    } catch (Throwable th6) {
                        th.addSuppressed(th6);
                    }
                } else {
                    res.close();
                }
            }
        }
        return tableColum;
    }

    /* JADX WARN: Failed to find 'out' block for switch in B:16:0x0074. Please report as an issue. */
    public static FetchByRangeReturnValue fetchByRange(ProxyResultSet handle, int count, TableDTO tableDTO) throws DataToolkitException {
        StringColumn stringColumn;
        Long.valueOf(System.currentTimeMillis());
        FetchByRangeReturnValue fetchByRangeReturnValue = new FetchByRangeReturnValue();
        fetchByRangeReturnValue.setErrCode(-1);
        if (handle != null) {
            ResultSet row = handle.getRs();
            try {
                ResultSetMetaData rsmd = row.getMetaData();
                List<Record> records = new ArrayList<>();
                boolean hasNext = true;
                for (int rangeCount = 1; rangeCount <= count && hasNext; rangeCount++) {
                    boolean next = row.next();
                    hasNext = next;
                    if (next) {
                        JobRecord jobRecord = new JobRecord();
                        for (int i = 1; i <= rsmd.getColumnCount(); i++) {
                            switch (rsmd.getColumnType(i)) {
                                case -4:
                                    Object binary2 = row.getObject(i);
                                    String contentL = "";
                                    if (binary2 != null) {
                                        contentL = EncodeUtil.bytesToHexString((byte[]) binary2);
                                    }
                                    stringColumn = new StringColumn(contentL);
                                    stringColumn.setName(rsmd.getColumnName(i));
                                    jobRecord.addColumn(stringColumn);
                                case -3:
                                    Object binary1 = row.getObject(i);
                                    String contentV = "";
                                    if (binary1 != null) {
                                        contentV = EncodeUtil.bytesToHexString((byte[]) binary1);
                                    }
                                    stringColumn = new StringColumn(contentV);
                                    stringColumn.setName(rsmd.getColumnName(i));
                                    jobRecord.addColumn(stringColumn);
                                case -2:
                                    Object binary = row.getObject(i);
                                    String contentB = "";
                                    if (binary != null) {
                                        contentB = EncodeUtil.bytesToHexString((byte[]) binary);
                                    }
                                    stringColumn = new StringColumn(contentB);
                                    stringColumn.setName(rsmd.getColumnName(i));
                                    jobRecord.addColumn(stringColumn);
                                case 0:
                                    String stringData = "";
                                    if (row.getObject(i) != null) {
                                        stringData = row.getObject(i).toString();
                                    }
                                    stringColumn = new StringColumn(stringData);
                                    stringColumn.setName(rsmd.getColumnName(i));
                                    jobRecord.addColumn(stringColumn);
                                case 2004:
                                    Blob blob = row.getBlob(i);
                                    String content = "";
                                    if (blob != null) {
                                        byte[] buffer = blob.getBytes(1L, (int) blob.length());
                                        content = EncodeUtil.bytesToHexString(buffer);
                                    }
                                    stringColumn = new StringColumn(content);
                                    stringColumn.setName(rsmd.getColumnName(i));
                                    jobRecord.addColumn(stringColumn);
                                case 2005:
                                    String contentC = "";
                                    try {
                                        Clob clob = row.getClob(i);
                                        if (clob != null) {
                                            Reader inStream = clob.getCharacterStream();
                                            char[] c = new char[(int) clob.length()];
                                            inStream.read(c);
                                            contentC = new String(c);
                                            inStream.close();
                                        }
                                    } catch (Exception e) {
                                        e.printStackTrace();
                                    }
                                    stringColumn = new StringColumn(contentC);
                                    stringColumn.setName(rsmd.getColumnName(i));
                                    jobRecord.addColumn(stringColumn);
                                case 2011:
                                    NClob nClob = row.getNClob(i);
                                    String contentN = "";
                                    if (nClob != null) {
                                        contentN = new String(nClob.getSubString(1L, (int) nClob.length()));
                                    }
                                    stringColumn = new StringColumn(contentN);
                                    stringColumn.setName(rsmd.getColumnName(i));
                                    jobRecord.addColumn(stringColumn);
                                default:
                                    String rowData = row.getString(i) == null ? "" : row.getString(i);
                                    stringColumn = new StringColumn(rowData);
                                    stringColumn.setName(rsmd.getColumnName(i));
                                    jobRecord.addColumn(stringColumn);
                            }
                        }
                        records.add(jobRecord);
                    }
                }
                if (hasNext) {
                    fetchByRangeReturnValue.setErrCode(0);
                } else {
                    fetchByRangeReturnValue.setErrCode(1);
                }
                fetchByRangeReturnValue.setErrMsg("success");
                fetchByRangeReturnValue.setRecords(records);
            } catch (Exception ex) {
                log.info(FETCH_BY_RANGE_ERROR, ex.getMessage());
                fetchByRangeReturnValue.setErrCode(-1);
                fetchByRangeReturnValue.setErrMsg(ex.getMessage());
            }
        }
        return fetchByRangeReturnValue;
    }

    public static RecordMetaData getColumns(ProxyConnection handle, TableDTO tableDTO) throws DataToolkitException {
        RecordMetaData record = new RecordMetaData();
        Connection conn = (Connection) handle.getConnection();
        String databaseName = handle.getDataSourceInfo().getSchema();
        String dbtype1 = handle.getDataSourceInfo().getType().toUpperCase();
        if (conn != null && databaseName != null) {
            UpdateableDataContext createJdbcDataContext = DataContextFactory.createJdbcDataContext(conn);
            Table table = null;
            String tableName = tableDTO.getTableName();
            if (GBASE8S.equals(dbtype1)) {
                Schema[] schemas = createJdbcDataContext.getSchemas();
                for (Schema sc : schemas) {
                    table = createJdbcDataContext.getSchemaByName(sc.getName()).getTableByName(tableName);
                    if (table != null) {
                        break;
                    }
                }
            } else {
                Schema schema = createJdbcDataContext.getSchemaByName(databaseName);
                if (schema == null) {
                    log.info("schema not exist");
                    throw new DataToolkitException("数据库【" + databaseName + "】不存在！");
                }
                table = schema.getTableByName(tableName);
            }
            if (table == null) {
                log.info("table not exist");
                throw new DataToolkitException("数据库表【" + tableName + "】不存在！");
            }
            Column[] clo = table.getColumns();
            for (Column row : clo) {
                MetadataColumn mdColumn = new MetadataColumn();
                mdColumn.getMetadata().setColumnNumber(row.getColumnNumber());
                mdColumn.getMetadata().setColumnSize(row.getColumnSize().intValue());
                mdColumn.getMetadata().setRemarks(row.getRemarks() == null ? "" : row.getRemarks());
                mdColumn.getMetadata().setNullable(row.isNullable().booleanValue());
                mdColumn.getMetadata().setPrimaryKey(row.isPrimaryKey());
                mdColumn.getMetadata().setType(DataToolkitAssemble.convertedColumnType(dbtype1, row.getType(), row.getNativeType()));
                mdColumn.getMetadata().setName(row.getName());
                record.addColumn(mdColumn);
            }
        }
        return record;
    }

    /* JADX WARN: Failed to find 'out' block for switch in B:15:0x0041. Please report as an issue. */
    /* JADX WARN: Removed duplicated region for block: B:22:0x0230 A[Catch: Exception -> 0x024f, TryCatch #0 {Exception -> 0x024f, blocks: (B:7:0x000b, B:11:0x001e, B:12:0x0029, B:14:0x0035, B:15:0x0041, B:16:0x0084, B:18:0x0093, B:19:0x00a0, B:22:0x0230, B:24:0x023e, B:26:0x00ae, B:28:0x00c1, B:29:0x00da, B:30:0x00e8, B:32:0x00fb, B:33:0x0108, B:34:0x0116, B:36:0x0129, B:37:0x0136, B:38:0x0144, B:40:0x0157, B:41:0x0164, B:42:0x0172, B:44:0x0185, B:45:0x019e, B:48:0x01b0, B:50:0x01bf, B:52:0x01f9, B:55:0x01f4, B:56:0x0207, B:59:0x021f, B:60:0x0217), top: B:6:0x000b, inners: #1 }] */
    /* JADX WARN: Removed duplicated region for block: B:25:0x023e A[SYNTHETIC] */
    /*
        Code decompiled incorrectly, please refer to instructions dump.
        To view partially-correct code enable 'Show inconsistent code' option in preferences
    */
    public static com.wst.data.safety.datasource.tool.datax.Record fetch(com.wst.data.safety.datasource.tool.entity.ProxyResultSet r8, boolean r9) throws com.wst.data.safety.datasource.tool.exception.DataToolkitException {
        /*
            Method dump skipped, instructions count: 610
            To view this dump change 'Code comments level' option to 'DEBUG'
        */
        throw new UnsupportedOperationException("Method not decompiled: com.wst.data.safety.datasource.tool.util.TablelUtil.fetch(com.wst.data.safety.datasource.tool.entity.ProxyResultSet, boolean):com.wst.data.safety.datasource.tool.datax.Record");
    }

    /* JADX WARN: Failed to find 'out' block for switch in B:15:0x0041. Please report as an issue. */
    /* JADX WARN: Removed duplicated region for block: B:22:0x024c A[Catch: Exception -> 0x026b, TryCatch #0 {Exception -> 0x026b, blocks: (B:7:0x000b, B:11:0x001e, B:12:0x0029, B:14:0x0035, B:15:0x0041, B:16:0x0084, B:18:0x0093, B:19:0x00a0, B:22:0x024c, B:24:0x025a, B:26:0x00ae, B:28:0x00c1, B:29:0x00da, B:30:0x00e8, B:32:0x00fb, B:33:0x0108, B:34:0x0116, B:36:0x0129, B:37:0x0136, B:38:0x0144, B:40:0x0157, B:41:0x0164, B:42:0x0172, B:44:0x0185, B:45:0x019e, B:48:0x01b0, B:50:0x01bf, B:52:0x01f9, B:55:0x01f4, B:56:0x0207, B:59:0x023d, B:60:0x0223, B:64:0x0233), top: B:6:0x000b, inners: #1 }] */
    /* JADX WARN: Removed duplicated region for block: B:25:0x025a A[SYNTHETIC] */
    /*
        Code decompiled incorrectly, please refer to instructions dump.
        To view partially-correct code enable 'Show inconsistent code' option in preferences
    */
    public static com.wst.data.safety.datasource.tool.datax.Record fetchForOracle(com.wst.data.safety.datasource.tool.entity.ProxyResultSet r8, boolean r9) throws com.wst.data.safety.datasource.tool.exception.DataToolkitException {
        /*
            Method dump skipped, instructions count: 638
            To view this dump change 'Code comments level' option to 'DEBUG'
        */
        throw new UnsupportedOperationException("Method not decompiled: com.wst.data.safety.datasource.tool.util.TablelUtil.fetchForOracle(com.wst.data.safety.datasource.tool.entity.ProxyResultSet, boolean):com.wst.data.safety.datasource.tool.datax.Record");
    }

    public static Record fetch(ProxyResultSet handle) throws DataToolkitException {
        return fetch(handle, false);
    }

    public static String getJdbcSchemaName(Schema schema, boolean usesCatalogsAsSchemas) {
        if (usesCatalogsAsSchemas) {
            return null;
        }
        return schema.getName();
    }

    public static String getCatalogName(Schema schema, boolean usesCatalogsAsSchemas, JdbcDataContext dataContext) {
        if (usesCatalogsAsSchemas) {
            return schema.getName();
        }
        return dataContext.getCatalogName();
    }

    public static boolean usesCatalogsAsSchemas(DatabaseMetaData metaData) {
        boolean z;
        boolean result = true;
        boolean result2 = null;
        try {
            try {
                result2 = metaData.getSchemas();
                while (result2.next()) {
                    if (!z) {
                        break;
                    }
                    result = false;
                }
                if (result2 != null) {
                    try {
                        result2.close();
                    } catch (SQLException e) {
                        log.info("databaseMetadata resultSet close failed");
                    }
                }
                return result2;
            } finally {
                if (result2 != null) {
                    try {
                        result2.close();
                    } catch (SQLException e2) {
                        log.info("databaseMetadata resultSet close failed");
                    }
                }
            }
        } catch (SQLException e3) {
            throw JdbcUtils.wrapException(e3, "retrieve schema and catalog metadata");
        }
    }

    public static List<String> getTablePath(TableDTO tableDTO, DataSourceInfoDTO dataSourceInfo) throws SQLException, ClassNotFoundException, InstantiationException, IllegalAccessException {
        String tableName = tableDTO.getTableName();
        List<String> tablePath = new ArrayList<>();
        Driver driver = (Driver) Class.forName((String) dataSourceInfo.getTokens().get("driverClass")).newInstance();
        Properties properties = new Properties();
        properties.put("user", dataSourceInfo.getTokens().get("username"));
        properties.put("password", dataSourceInfo.getTokens().get("password"));
        String url = (String) dataSourceInfo.getTokens().get("url");
        String prefix = url.substring(0, url.lastIndexOf("/") + 1);
        String suffix = url.substring(url.lastIndexOf(":"));
        Connection connection = driver.connect(prefix + "sysmaster" + suffix, properties);
        Statement statement = connection.createStatement();
        if (tableDTO.getType().equalsIgnoreCase(GBASE)) {
            String sql = "SELECT\n\tst.dbsname,\n\tst.tabname,\n\tsc.fname\nFROM\n\tsystabnames st\nLEFT JOIN syschunks sc ON\n\tst.dbsnum = sc.dbsnum\nWHERE\n     tabname NOT LIKE 'sys%'\nAND  dbsname NOT IN ('sysuser','sysmaster','sysutils','sysadmin','gbasedb','rootdbs','llogdbs','plogdbs','sbspace1','tmpdbs1') and st.tabname = '" + tableName + "'";
            ResultSet resultSet = statement.executeQuery(sql);
            Throwable th = null;
            while (resultSet.next()) {
                try {
                    try {
                        tablePath.add(resultSet.getString(3).trim());
                    } finally {
                    }
                } catch (Throwable th2) {
                    if (resultSet != null) {
                        if (th != null) {
                            try {
                                resultSet.close();
                            } catch (Throwable th3) {
                                th.addSuppressed(th3);
                            }
                        } else {
                            resultSet.close();
                        }
                    }
                    throw th2;
                }
            }
            if (resultSet != null) {
                if (0 != 0) {
                    try {
                        resultSet.close();
                    } catch (Throwable th4) {
                        th.addSuppressed(th4);
                    }
                } else {
                    resultSet.close();
                }
            }
        }
        return tablePath;
    }

    public static String getTableRemarks(Statement statement, TableDTO tableDTO) throws SQLException {
        String tableName = tableDTO.getTableName();
        String comment = "";
        if (tableDTO.getType().equalsIgnoreCase(ORACLE)) {
            String sql = "select COMMENTS from user_tab_comments WHERE TABLE_NAME = '" + tableName + "'";
            ResultSet resultSet = statement.executeQuery(sql);
            Throwable th = null;
            while (resultSet.next()) {
                try {
                    try {
                        comment = resultSet.getString(1);
                    } finally {
                    }
                } catch (Throwable th2) {
                    if (resultSet != null) {
                        if (th != null) {
                            try {
                                resultSet.close();
                            } catch (Throwable th3) {
                                th.addSuppressed(th3);
                            }
                        } else {
                            resultSet.close();
                        }
                    }
                    throw th2;
                }
            }
            if (resultSet != null) {
                if (0 != 0) {
                    try {
                        resultSet.close();
                    } catch (Throwable th4) {
                        th.addSuppressed(th4);
                    }
                } else {
                    resultSet.close();
                }
            }
        }
        return comment;
    }

    public static List<TableDTO> getTableNameBySchema(Statement statement, String schema) throws SQLException {
        List<TableDTO> list = new ArrayList<>();
        String sql = "SELECT TABLE_NAME , TABLE_TYPE FROM INFORMATION_SCHEMA.TABLES WHERE TABLE_SCHEMA = '" + schema + "'";
        ResultSet resultSet = statement.executeQuery(sql);
        Throwable th = null;
        while (resultSet.next()) {
            try {
                try {
                    TableDTO table = new TableDTO();
                    table.setTableName(resultSet.getString(1));
                    table.setType(resultSet.getString(2));
                    list.add(table);
                } finally {
                }
            } catch (Throwable th2) {
                if (resultSet != null) {
                    if (th != null) {
                        try {
                            resultSet.close();
                        } catch (Throwable th3) {
                            th.addSuppressed(th3);
                        }
                    } else {
                        resultSet.close();
                    }
                }
                throw th2;
            }
        }
        if (resultSet != null) {
            if (0 != 0) {
                try {
                    resultSet.close();
                } catch (Throwable th4) {
                    th.addSuppressed(th4);
                }
            } else {
                resultSet.close();
            }
        }
        return list;
    }

    public static Map<String, String> getColumnRemarks(Statement statement, TableDTO tableDTO) throws SQLException {
        HashMap<String, String> colRemarksMap = Maps.newHashMap();
        String tableName = tableDTO.getTableName();
        if (tableDTO.getType().equalsIgnoreCase(ORACLE)) {
            String sql = "select COLUMN_NAME,COMMENTS from user_col_comments WHERE TABLE_NAME = '" + tableName + "'";
            ResultSet resultSet = statement.executeQuery(sql);
            Throwable th = null;
            while (resultSet.next()) {
                try {
                    try {
                        colRemarksMap.put(resultSet.getString(1), resultSet.getString(2));
                    } finally {
                    }
                } catch (Throwable th2) {
                    if (resultSet != null) {
                        if (th != null) {
                            try {
                                resultSet.close();
                            } catch (Throwable th3) {
                                th.addSuppressed(th3);
                            }
                        } else {
                            resultSet.close();
                        }
                    }
                    throw th2;
                }
            }
            if (resultSet != null) {
                if (0 != 0) {
                    try {
                        resultSet.close();
                    } catch (Throwable th4) {
                        th.addSuppressed(th4);
                    }
                } else {
                    resultSet.close();
                }
            }
        }
        return colRemarksMap;
    }
}
